==> scangearmp2-source-3.50-1.tar.gz: scangearmp2-source-3.50-1/scangearmp2/src/cnmsstrings.h <==
/*
 *  ScanGear MP for Linux
 *  Copyright CANON INC. 2007-2017
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; version 2 of the License.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307, USA.
 *
 * NOTE:
 *  - As a special exception, this program is permissible to link with the
 *    libraries released as the binary modules.
 *  - If you write modifications of your own for these programs, it is your
 *    choice whether to permit this exception to apply to your modifications.
 *    If you do not wish that, delete this exception.
*/


#ifndef	_CNMSSTRINGS_H_
#define	_CNMSSTRINGS_H_

/* N_ macro */
#include "support.h"

#define	STR_CNMS_LS_007_VER_NUM		"3.50"
#define	STR_CNMS_LS_007_YEAR_BEGIN	"2007"
#define	STR_CNMS_LS_007_YEAR_END	"2017"

/*STR_CNMS_LS_001_01*/
#define	STR_CNMS_LS_001_01	N_( "Scanner" )
/*STR_CNMS_LS_001_02*/
#define	STR_CNMS_LS_001_02	N_( "Scan Mode:" )
/*STR_CNMS_LS_001_03*/
#define	STR_CNMS_LS_001_03	N_( "Select Source:" )
/*STR_CNMS_LS_001_04*/
#define	STR_CNMS_LS_001_04	N_( "Color Mode:" )
/*STR_CNMS_LS_001_05*/
#define	STR_CNMS_LS_001_05	N_( "Paper Size:" )
/*STR_CNMS_LS_001_06*/
#define	STR_CNMS_LS_001_06	N_( "Scan (JPEG)" )
/*STR_CNMS_LS_001_07*/
#define	STR_CNMS_LS_001_07	N_( "Scan (PDF)" )
/*STR_CNMS_LS_001_08*/
#define	STR_CNMS_LS_001_08	N_( "Close" )
/*STR_CNMS_LS_001_09*/
#define	STR_CNMS_LS_001_09	N_( "Version" )
/*STR_CNMS_LS_002_01*/
#define	STR_CNMS_LS_002_01	N_( "Platen" )
/*STR_CNMS_LS_002_02*/
#define	STR_CNMS_LS_002_02	N_( "ADF Simplex" )
/*STR_CNMS_LS_002_03*/
#define	STR_CNMS_LS_002_03	N_( "ADF Duplex (Long-side Binding)" )
/*STR_CNMS_LS_002_04*/
#define	STR_CNMS_LS_002_04	N_( "ADF Duplex (Short-side Binding)" )
/*STR_CNMS_LS_003_01*/
#define	STR_CNMS_LS_003_01	N_( "Document" )
/*STR_CNMS_LS_003_02*/
#define	STR_CNMS_LS_003_02	N_( "Photo" )
/*STR_CNMS_LS_004_01*/
#define	STR_CNMS_LS_004_01	N_( "Color" )
/*STR_CNMS_LS_004_02*/
#define	STR_CNMS_LS_004_02	N_( "Grayscale" )
/*STR_CNMS_LS_005_01*/
#define	STR_CNMS_LS_005_01	N_( "Card" )
/*STR_CNMS_LS_005_02*/
#define	STR_CNMS_LS_005_02	N_( "L Landscape" )
/*STR_CNMS_LS_005_03*/
#define	STR_CNMS_LS_005_03	N_( "L Portrait" )
/*STR_CNMS_LS_005_04*/
#define	STR_CNMS_LS_005_04	N_( "4\" x 6\" Landscape" )
/*STR_CNMS_LS_005_05*/
#define	STR_CNMS_LS_005_05	N_( "4\" x 6\" Portrait" )
/*STR_CNMS_LS_005_06*/
#define	STR_CNMS_LS_005_06	N_( "Hagaki Landscape" )
/*STR_CNMS_LS_005_07*/
#define	STR_CNMS_LS_005_07	N_( "Hagaki Portrait" )
/*STR_CNMS_LS_005_08*/
#define	STR_CNMS_LS_005_08	N_( "2L Landscape" )
/*STR_CNMS_LS_005_09*/
#define	STR_CNMS_LS_005_09	N_( "2L Portrait" )
/*STR_CNMS_LS_005_10*/
#define	STR_CNMS_LS_005_10	N_( "A5" )
/*STR_CNMS_LS_005_11*/
#define	STR_CNMS_LS_005_11	N_( "B5" )
/*STR_CNMS_LS_005_12*/
#define	STR_CNMS_LS_005_12	N_( "A4" )
/*STR_CNMS_LS_005_13*/
#define	STR_CNMS_LS_005_13	N_( "Letter" )

#define	STR_CNMS_LS_007_01		"ScanGear"
#define	STR_CNMS_LS_007_02		"ScanGear MP"

/*STR_CNMS_LS_007_03*/
#define	STR_CNMS_LS_007_03	N_( "Version %s" )
/*STR_CNMS_LS_007_04*/
#define	STR_CNMS_LS_007_04	N_( "Copyright CANON INC. %s-%s" )
/*STR_CNMS_LS_008_01*/
#define	STR_CNMS_LS_008_01	N_( "Save Scan Image" )
/*STR_CNMS_LS_008_02*/
#define	STR_CNMS_LS_008_02	N_( "Save" )
/*STR_CNMS_LS_008_03*/
#define	STR_CNMS_LS_008_03	N_( "The file name is not specified." )
/*STR_CNMS_LS_008_04*/
#define	STR_CNMS_LS_008_04	N_( "The same file name already exists.\nAre you sure to overwrite it?" )
/*STR_CNMS_LS_008_05*/
#define	STR_CNMS_LS_008_05	N_( "You do not have permission to access the specified file.\nSpecify another file name or save the file in another directory." )
/*STR_CNMS_LS_008_06*/
#define	STR_CNMS_LS_008_06	N_( "The specified directory does not exist or you do not have permission to access the directory.\nSave the file in another directory." )
/*STR_CNMS_LS_008_07*/
#define	STR_CNMS_LS_008_07	N_( "The specified file name is invalid.\nSpecify another file name." )
/*STR_CNMS_LS_009_01*/
#define	STR_CNMS_LS_009_01	N_( "Scanning..." )
/*STR_CNMS_LS_009_02*/
#define	STR_CNMS_LS_009_02	N_( "Saving..." )
/*STR_CNMS_LS_009_03*/
#define	STR_CNMS_LS_009_03	N_( "Saved the scan result." )
/*STR_CNMS_LS_009_04*/
#define	STR_CNMS_LS_009_04	N_( "%d page(s)" )
/*STR_CNMS_LS_009_05*/
#define	STR_CNMS_LS_009_05	N_( "Canceling..." )
/*STR_CNMS_LS_010_01*/
#define	STR_CNMS_LS_010_01	N_( "Scan has been canceled." )
/*STR_CNMS_LS_010_02*/
#define	STR_CNMS_LS_010_02	N_( "Scan has been canceled. Check the printer." )
/*STR_CNMS_LS_010_03*/
#define	STR_CNMS_LS_010_03	N_( "The printer is in operation. Check the printer.\nScanner driver will be closed." )
/*STR_CNMS_LS_010_04*/
#define	STR_CNMS_LS_010_04	N_( "An error has occurred while scanning. Check the printer.\nScanner driver will be closed." )
/*STR_CNMS_LS_010_05*/
#define	STR_CNMS_LS_010_05	N_( "Cannot communicate with scanner.\nScanner driver will be closed." )
/*STR_CNMS_LS_010_06*/
#define	STR_CNMS_LS_010_06	N_( "There is not enough free disk space to complete the scan.\nScanner driver will be closed." )
/*STR_CNMS_LS_010_07*/
#define	STR_CNMS_LS_010_07	N_( "Cannot find available scanners.\n\nCable may be disconnected or scanner may be turned off.\nCheck the scanner status, and then try again." )
/*STR_CNMS_LS_010_08*/
#define	STR_CNMS_LS_010_08	N_( "The ADF (Auto Document Feeder) is empty. \nPlace paper in the ADF." )
/*STR_CNMS_LS_010_09*/
#define	STR_CNMS_LS_010_09	N_( "Internal Error occurred.\nScanner driver will be closed." )
/*STR_CNMS_LS_011_01*/
#define	STR_CNMS_LS_011_01	N_( "Select Scanner" )
/*STR_CNMS_LS_011_02*/
#define	STR_CNMS_LS_011_02	N_( "No scanners detected." )
/*STR_CNMS_LS_011_03*/
#define	STR_CNMS_LS_011_03	N_( "Update Scanner List" )
/*STR_CNMS_LS_011_04*/
#define	STR_CNMS_LS_011_04	N_( "OK" )
/*STR_CNMS_LS_011_05*/
#define	STR_CNMS_LS_011_05	N_( "Cancel" )
/*STR_CNMS_LS_012_01*/
#define	STR_CNMS_LS_012_01	N_( "Searching..." )
/*STR_CNMS_LS_012_02*/
#define	STR_CNMS_LS_012_02	N_( "Searching for scanners." )
/*STR_CNMS_LS_012_03*/
#define	STR_CNMS_LS_012_03	N_( "Updating the scanner list." )


#endif /* _CNMSSTRINGS_H_ */

==> scangearmp2-source-4.30-1.tar.gz: scangearmp2-source-4.30-1/scangearmp2/src/cnmsstrings.h <==
/*
 *  ScanGear MP for Linux
 *  Copyright CANON INC. 2007-2021
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; version 2 of the License.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307, USA.
 *
 * NOTE:
 *  - As a special exception, this program is permissible to link with the
 *    libraries released as the binary modules.
 *  - If you write modifications of your own for these programs, it is your
 *    choice whether to permit this exception to apply to your modifications.
 *    If you do not wish that, delete this exception.
*/


#ifndef	_CNMSSTRINGS_H_
#define	_CNMSSTRINGS_H_

/* N_ macro */
#include "support.h"

#define	STR_CNMS_LS_007_VER_NUM		"4.30"
#define	STR_CNMS_LS_007_YEAR_BEGIN	"2007"
#define	STR_CNMS_LS_007_YEAR_END	"2021"

/*STR_CNMS_LS_001_01*/
#define	STR_CNMS_LS_001_01	N_( "Scanner" )
/*STR_CNMS_LS_001_02*/
#define	STR_CNMS_LS_001_02	N_( "Scan Mode:" )
/*STR_CNMS_LS_001_03*/
#define	STR_CNMS_LS_001_03	N_( "Select Source:" )
/*STR_CNMS_LS_001_04*/
#define	STR_CNMS_LS_001_04	N_( "Color Mode:" )
/*STR_CNMS_LS_001_05*/
#define	STR_CNMS_LS_001_05	N_( "Paper Size:" )
/*STR_CNMS_LS_001_06*/
#define	STR_CNMS_LS_001_06	N_( "Scan (JPEG)" )
/*STR_CNMS_LS_001_07*/
#define	STR_CNMS_LS_001_07	N_( "Scan (PDF)" )
/*STR_CNMS_LS_001_08*/
#define	STR_CNMS_LS_001_08	N_( "Close" )
/*STR_CNMS_LS_001_09*/
#define	STR_CNMS_LS_001_09	N_( "Version" )
/*STR_CNMS_LS_002_01*/
#define	STR_CNMS_LS_002_01	N_( "Platen" )
/*STR_CNMS_LS_002_02*/
#define	STR_CNMS_LS_002_02	N_( "ADF Simplex" )
/*STR_CNMS_LS_002_03*/
#define	STR_CNMS_LS_002_03	N_( "ADF Duplex (Long-side Binding)" )
/*STR_CNMS_LS_002_04*/
#define	STR_CNMS_LS_002_04	N_( "ADF Duplex (Short-side Binding)" )
/*STR_CNMS_LS_003_01*/
#define	STR_CNMS_LS_003_01	N_( "Document" )
/*STR_CNMS_LS_003_02*/
#define	STR_CNMS_LS_003_02	N_( "Photo" )
/*STR_CNMS_LS_004_01*/
#define	STR_CNMS_LS_004_01	N_( "Color" )
/*STR_CNMS_LS_004_02*/
#define	STR_CNMS_LS_004_02	N_( "Grayscale" )
/*STR_CNMS_LS_005_01*/
#define	STR_CNMS_LS_005_01	N_( "Card" )
/*STR_CNMS_LS_005_02*/
#define	STR_CNMS_LS_005_02	N_( "L Landscape" )
/*STR_CNMS_LS_005_03*/
#define	STR_CNMS_LS_005_03	N_( "L Portrait" )
/*STR_CNMS_LS_005_04*/
#define	STR_CNMS_LS_005_04	N_( "4\" x 6\" Landscape" )
/*STR_CNMS_LS_005_05*/
#define	STR_CNMS_LS_005_05	N_( "4\" x 6\" Portrait" )
/*STR_CNMS_LS_005_06*/
#define	STR_CNMS_LS_005_06	N_( "Hagaki Landscape" )
/*STR_CNMS_LS_005_07*/
#define	STR_CNMS_LS_005_07	N_( "Hagaki Portrait" )
/*STR_CNMS_LS_005_08*/
#define	STR_CNMS_LS_005_08	N_( "2L Landscape" )
/*STR_CNMS_LS_005_09*/
#define	STR_CNMS_LS_005_09	N_( "2L Portrait" )
/*STR_CNMS_LS_005_10*/
#define	STR_CNMS_LS_005_10	N_( "A5" )
/*STR_CNMS_LS_005_11*/
#define	STR_CNMS_LS_005_11	N_( "B5" )
/*STR_CNMS_LS_005_12*/
#define	STR_CNMS_LS_005_12	N_( "A4" )
/*STR_CNMS_LS_005_13*/
#define	STR_CNMS_LS_005_13	N_( "Letter" )

#define	STR_CNMS_LS_007_01		"ScanGear"
#define	STR_CNMS_LS_007_02		"ScanGear MP"

/*STR_CNMS_LS_007_03*/
#define	STR_CNMS_LS_007_03	N_( "Version %s" )
/*STR_CNMS_LS_007_04*/
#define	STR_CNMS_LS_007_04	N_( "Copyright CANON INC. %s-%s" )
/*STR_CNMS_LS_008_01*/
#define	STR_CNMS_LS_008_01	N_( "Save Scan Image" )
/*STR_CNMS_LS_008_02*/
#define	STR_CNMS_LS_008_02	N_( "Save" )
/*STR_CNMS_LS_008_03*/
#define	STR_CNMS_LS_008_03	N_( "The file name is not specified." )
/*STR_CNMS_LS_008_04*/
#define	STR_CNMS_LS_008_04	N_( "The same file name already exists.\nAre you sure to overwrite it?" )
/*STR_CNMS_LS_008_05*/
#define	STR_CNMS_LS_008_05	N_( "You do not have permission to access the specified file.\nSpecify another file name or save the file in another directory." )
/*STR_CNMS_LS_008_06*/
#define	STR_CNMS_LS_008_06	N_( "The specified directory does not exist or you do not have permission to access the directory.\nSave the file in another directory." )
/*STR_CNMS_LS_008_07*/
#define	STR_CNMS_LS_008_07	N_( "The specified file name is invalid.\nSpecify another file name." )
/*STR_CNMS_LS_009_01*/
#define	STR_CNMS_LS_009_01	N_( "Scanning..." )
/*STR_CNMS_LS_009_02*/
#define	STR_CNMS_LS_009_02	N_( "Saving..." )
/*STR_CNMS_LS_009_03*/
#define	STR_CNMS_LS_009_03	N_( "Saved the scan result." )
/*STR_CNMS_LS_009_04*/
#define	STR_CNMS_LS_009_04	N_( "%d page(s)" )
/*STR_CNMS_LS_009_05*/
#define	STR_CNMS_LS_009_05	N_( "Canceling..." )
/*STR_CNMS_LS_010_01*/
#define	STR_CNMS_LS_010_01	N_( "Scan has been canceled." )
/*STR_CNMS_LS_010_02*/
#define	STR_CNMS_LS_010_02	N_( "Scan has been canceled. Check the printer." )
/*STR_CNMS_LS_010_03*/
#define	STR_CNMS_LS_010_03	N_( "The printer is in operation. Check the printer.\nScanner driver will be closed." )
/*STR_CNMS_LS_010_04*/
#define	STR_CNMS_LS_010_04	N_( "An error has occurred while scanning. Check the printer.\nScanner driver will be closed." )
/*STR_CNMS_LS_010_05*/
#define	STR_CNMS_LS_010_05	N_( "Cannot communicate with scanner.\nScanner driver will be closed." )
/*STR_CNMS_LS_010_06*/
#define	STR_CNMS_LS_010_06	N_( "There is not enough free disk space to complete the scan.\nScanner driver will be closed." )
/*STR_CNMS_LS_010_07*/
#define	STR_CNMS_LS_010_07	N_( "Cannot find available scanners.\n\nCable may be disconnected or scanner may be turned off.\nCheck the scanner status, and then try again." )
/*STR_CNMS_LS_010_08*/
#define	STR_CNMS_LS_010_08	N_( "The ADF (Auto Document Feeder) is empty. \nPlace paper in the ADF." )
/*STR_CNMS_LS_010_09*/
#define	STR_CNMS_LS_010_09	N_( "Internal Error occurred.\nScanner driver will be closed." )
/*STR_CNMS_LS_011_01*/
#define	STR_CNMS_LS_011_01	N_( "Select Scanner" )
/*STR_CNMS_LS_011_02*/
#define	STR_CNMS_LS_011_02	N_( "No scanners detected." )
/*STR_CNMS_LS_011_03*/
#define	STR_CNMS_LS_011_03	N_( "Update Scanner List" )
/*STR_CNMS_LS_011_04*/
#define	STR_CNMS_LS_011_04	N_( "OK" )
/*STR_CNMS_LS_011_05*/
#define	STR_CNMS_LS_011_05	N_( "Cancel" )
/*STR_CNMS_LS_012_01*/
#define	STR_CNMS_LS_012_01	N_( "Searching..." )
/*STR_CNMS_LS_012_02*/
#define	STR_CNMS_LS_012_02	N_( "Searching for scanners." )
/*STR_CNMS_LS_012_03*/
#define	STR_CNMS_LS_012_03	N_( "Updating the scanner list." )
/*STR_CNMS_LS_010_10*/
#define	STR_CNMS_LS_010_10	N_( "Release the lock switch, detach the USB cable and reconnect.\nScanner driver will be closed." )
/*STR_CNMS_LS_010_11*/
#define	STR_CNMS_LS_010_11	N_( "Scanner initialization is in progress. Scan after it is complete." )


#endif /* _CNMSSTRINGS_H_ */
